Class: OpenTok::Session
- Inherits:
-
Object
- Object
- OpenTok::Session
- Defined in:
- lib/opentok/session.rb
Overview
Represents an OpenTok session.
Use the OpenTok.createSession() method to create an OpenTok session. Use the session_id property of the Session object to get the session ID.
Instance Attribute Summary collapse
-
#location ⇒ String
readonly
The location hint IP address.
-
#media_mode ⇒ String
readonly
Set to :routed if the session uses the OpenTok Media Router or to :relayed if the session attempts to transmit streams directly between clients.
-
#session_id ⇒ String
readonly
The session ID.
Instance Method Summary collapse
-
#generate_token(options) ⇒ String
Generates a token.
Instance Attribute Details
#location ⇒ String (readonly)
The location hint IP address. See the OpenTok.createSession() method.
43 44 45 |
# File 'lib/opentok/session.rb', line 43 def location @location end |
#media_mode ⇒ String (readonly)
Set to :routed if the session uses the OpenTok Media Router or to :relayed if the session attempts to transmit streams directly between clients.
43 44 45 |
# File 'lib/opentok/session.rb', line 43 def media_mode @media_mode end |
#session_id ⇒ String (readonly)
The session ID.
43 44 45 |
# File 'lib/opentok/session.rb', line 43 def session_id @session_id end |
Instance Method Details
#generate_token(options) ⇒ String
Generates a token.
43 44 45 46 47 48 49 50 51 52 53 54 55 56 57 58 59 60 61 62 63 64 65 66 67 68 69 70 71 72 73 74 75 |
# File 'lib/opentok/session.rb', line 43 class Session include TokenGenerator generates_tokens({ :api_key => ->(instance) { instance.api_key }, :api_secret => ->(instance) { instance.api_secret }, :session_id => ->(instance) { instance.session_id } }) attr_reader :session_id, :media_mode, :location, :api_key, :api_secret # @private # this implementation doesn't completely understand the format of a Session ID # that is intentional, that is too much responsibility. def self.belongs_to_api_key?(session_id, api_key) encoded = session_id[2..session_id.length] .gsub('-', '+') .gsub('_', '/') decoded = Base64.decode64(encoded) decoded.include? api_key end # @private def initialize(api_key, api_secret, session_id, opts={}) @api_key, @api_secret, @session_id = api_key, api_secret, session_id @media_mode, @location = opts.fetch(:media_mode, :routed), opts[:location] end # @private def to_s @session_id end end |